@@ -21,7 +21,7 @@ describe 'cinder::backend::defaults' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts)
+        facts.merge!(OSDefaults.get_facts())
       end
 
       it_behaves_like 'cinder backend defaults'
