@@ -125,7 +125,7 @@ describe 'cinder::logging' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:os_workers => 8}))
+        facts.merge(OSDefaults.get_facts())
       end
 
       it_behaves_like 'cinder-logging'
