@@ -10,31 +10,28 @@ describe 'cinder::backend::netapp' do
       :netapp_login                 => 'netapp',
       :netapp_password              => 'password',
       :netapp_server_hostname       => '127.0.0.2',
-      :netapp_vfiler                => 'netapp_vfiler',
       :netapp_vserver               => 'netapp_vserver',
-      :netapp_partner_backend_name  => 'fc2',
       :netapp_copyoffload_tool_path => '/tmp/na_copyoffload_64',
-      :netapp_controller_ips        => '10.0.0.2,10.0.0.3',
-      :netapp_sa_password           => 'password',
     }
   end
 
   let :default_params do
     {
-      :backend_availability_zone   => '<SERVICE DEFAULT>',
-      :netapp_server_port          => '80',
-      :netapp_size_multiplier      => '1.2',
-      :netapp_storage_family       => 'ontap_cluster',
-      :netapp_storage_protocol     => 'nfs',
-      :netapp_transport_type       => 'http',
-      :expiry_thres_minutes        => '720',
-      :thres_avl_size_perc_start   => '20',
-      :thres_avl_size_perc_stop    => '60',
-      :nfs_shares_config           => '/etc/cinder/shares.conf',
-      :nfs_mount_options           => '<SERVICE DEFAULT>',
-      :netapp_webservice_path      => '/devmgr/v2',
-      :nas_secure_file_operations  => '<SERVICE DEFAULT>',
-      :nas_secure_file_permissions => '<SERVICE DEFAULT>',
+      :backend_availability_zone    => '<SERVICE DEFAULT>',
+      :netapp_server_port           => '<SERVICE DEFAULT>',
+      :netapp_size_multiplier       => '<SERVICE DEFAULT>',
+      :netapp_storage_family        => '<SERVICE DEFAULT>',
+      :netapp_storage_protocol      => 'nfs',
+      :netapp_transport_type        => '<SERVICE DEFAULT>',
+      :netapp_vserver               => '<SERVICE DEFAULT>',
+      :expiry_thres_minutes         => '<SERVICE DEFAULT>',
+      :thres_avl_size_perc_start    => '<SERVICE DEFAULT>',
+      :thres_avl_size_perc_stop     => '<SERVICE DEFAULT>',
+      :nfs_shares_config            => '/etc/cinder/shares.conf',
+      :netapp_copyoffload_tool_path => '<SERVICE DEFAULT>',
+      :nfs_mount_options            => '<SERVICE DEFAULT>',
+      :nas_secure_file_operations   => '<SERVICE DEFAULT>',
+      :nas_secure_file_permissions  => '<SERVICE DEFAULT>',
     }
   end
 
@@ -53,7 +50,6 @@ describe 'cinder::backend::netapp' do
 
     it {
       is_expected.to contain_cinder_config('netapp/netapp_password').with_secret( true )
-      is_expected.to contain_cinder_config('netapp/netapp_sa_password').with_secret( true )
     }
   end
 
@@ -70,14 +66,6 @@ describe 'cinder::backend::netapp' do
       it_behaves_like 'netapp volume driver'
     end
 
-    context 'with netapp_storage_family eseries' do
-      before do
-        params.merge!( :netapp_storage_family => 'eseries' )
-      end
-
-      it { is_expected.to contain_cinder_config('netapp/use_multipath_for_image_xfer').with_value('true') }
-    end
-
     context 'with nfs_mount_options' do
       before do
         params.merge!( :nfs_mount_options => 'rw,proto=tcp,sec=sys' )
